@@ -33,7 +33,6 @@
 #include "kraftsettings.h"
 #include "kraftdb.h"
 #include "numbercycle.h"
-#include "defaultprovider.h"
 
 /**
 @author Klaas Freitag
@@ -161,6 +160,16 @@ bool DocType::allowAlternative()
   return re;
 }
 
+bool DocType::pricesVisible()
+{
+    bool re = true;
+    if( mAttributes.contains("HidePrices")) {
+        re = false;
+    }
+    return re;
+}
+
+
 QStringList DocType::follower()
 {
   return mFollowerList;
@@ -217,47 +226,56 @@ QString DocType::templateFile( const QString& lang )
   KStandardDirs stdDirs;
   QString tmplFile;
 
-  QString reportFileName = name().toLower() + QString( ".trml" );
+  QString reportFileName = QString( "%1.trml").arg( name().toLower() );
+  reportFileName.replace(QChar(' '), QChar('_'));
 
   if ( mAttributes.hasAttribute( "docTemplateFile" ) ) {
     tmplFile = mAttributes["docTemplateFile"].value().toString();
-    if( tmplFile.isEmpty() ) {
-      // happens in case of strange db content
-      tmplFile = "invoice.trml";  // the default doc
+    if( !tmplFile.isEmpty() ) {
+        return tmplFile;
     }
   }
 
-  if ( ! QFile::exists( tmplFile ) ) {
-    // first, read language dependant in case its not 'C' or empty
-    QString findFile;
-    QString language( lang );
-    if( language.isEmpty() ) {
-      language = DefaultProvider::self()->locale()->country();
-    }
-    if( !( language.isEmpty() && language != QChar('C') ) ) {
-      findFile  = QString( "kraft/reports/%1/%2" ).arg( language ).arg( reportFileName );
-      kDebug() << "Searching for lang report: " << findFile;
-      tmplFile = stdDirs.findResource( "data", findFile );
-
-      if( !QFile::exists( tmplFile )) {
-        // if this cant be found, search for a lang dependant invoice.trml
-        findFile = QString( "kraft/reports/%1/invoice.trml" ).arg( language );
-        kDebug() << "Searching more for lang report: " << findFile;
-        tmplFile = stdDirs.findResource( "data", findFile );
-      }
-    }
-
-    if( !QFile::exists(tmplFile) ) {
-      // now try the old language indep search
-      findFile = "kraft/reports/" + reportFileName;
-
-      tmplFile = stdDirs.findResource( "data", findFile );
-
-      if ( !QFile::exists( tmplFile ) ) {
-        tmplFile = defaultTemplateFile();
-      }
-    }
+  // Try to find it from the installation
+  QStringList searchList;
+  if( !lang.isEmpty() ) {
+      searchList << QString("kraft/reports/%1/%2").arg(lang).arg(reportFileName);
   }
+  searchList << QString("kraft/reports/%1").arg(reportFileName);
+  if( !lang.isEmpty() ) {
+      searchList << QString("kraft/reports/%1/invoice.trml").arg(lang);
+  }
+  searchList << QLatin1String("kraft/reports/invoice.trml");
+
+  foreach( QString searchPath, searchList ) {
+     const QString tFile = KStandardDirs::locate( "data", searchPath );
+
+      if( !tFile.isEmpty() && tFile != searchPath && QFile::exists( tFile )) {
+          tmplFile = tFile;
+          kDebug() << "Found template file " << tmplFile;
+          break;
+      }
+  }
+
+  if( tmplFile.isEmpty() ) {
+      const QString prjPath = QString::fromUtf8(qgetenv( "KRAFT_HOME" ));
+
+      if( tmplFile.isEmpty() && !prjPath.isEmpty() ) {
+          foreach( QString searchPath, searchList ) {
+              const QString tFile = prjPath + searchPath;
+              if( !tFile.isEmpty() && QFile::exists(tFile) ) {
+                  kDebug() << "Found template file " << tFile;
+                  tmplFile = tFile;
+                  break;
+              }
+          }
+      }
+  }
+
+  if( tmplFile.isEmpty() ) {
+      kDebug() << "unable to find a template file for " << name();
+  }
+
   return tmplFile;
 }
 
@@ -347,6 +365,7 @@ QString DocType::generateDocumentIdent( KraftDoc *doc, int id )
    * %c - the customer id from kaddressbook
    * %i - the uniq identifier from db.
    * %type - the localised doc type (offer, invoice etc.)
+   * %uid  - the customer uid
    */
 
   QString pattern = identTemplate();
@@ -401,9 +420,11 @@ QString DocType::generateDocumentIdent( KraftDoc *doc, int id )
   if ( doc ) {
     m[ "%c" ] = doc->addressUid();
     m[ "%type" ] = doc->docType();
+    m[ "%uid" ] = doc->addressUid();
   } else {
-    m[ "%c"] = QString(" <addressUid>" );
+    m[ "%c"] = QLatin1String(" <addressUid>" );
     m[ "%type" ] = mName;
+    m[ "%uid" ] = QLatin1String("<uid>");
   }
 
   QString re = KraftDB::self()->replaceTagsInWord( pattern, m );
