@@ -209,7 +209,7 @@ void KraftView::setup( DocGuardedPtr doc )
   m_doc = doc;
 
   setupDocHeaderView();
-  setupPositions();
+  setupItems();
   setupFooter();
   setCaption( m_doc->docIdentifier() );
   slotSwitchToPage( KraftDoc::Header );
@@ -236,7 +236,6 @@ void KraftView::slotSwitchToPage( int id )
   mDetailHeader->setPalette( palette );
 
   mAssistant->slotSelectDocPart( mViewStack->currentIndex() );
-  // mAssistant->postCard()->renderDoc( mViewStack->id( mViewStack->visibleWidget() ) );
 }
 
 void KraftView::slotShowTemplates( bool )
@@ -271,10 +270,10 @@ void KraftView::setupDocHeaderView()
     connect( edit, SIGNAL(pickAddressee()), this, SLOT(slotPickAddressee()) );
 }
 
-void KraftView::setupPositions()
+void KraftView::setupItems()
 {
     KraftDocPositionsEdit *edit = new KraftDocPositionsEdit( mainWidget() );
-    mViewStack->addWidget( edit ); // , KraftDoc::Positions );
+    mDocPosEditorIndx = mViewStack->addWidget( edit ); // , KraftDoc::Positions );
 
     m_positionScroll = edit->positionScroll();
 
@@ -304,7 +303,6 @@ void KraftView::redrawDocument( )
 
     kDebug() << "Loaded address uid from database " << mContactUid << endl;
     if( ! mContactUid.isEmpty() ) {
-
       mAddressProvider->getAddressee( mContactUid );
     }
 
@@ -363,16 +361,19 @@ void KraftView::redrawDocPositions( )
     // the doc has no positions yet. Let's show a help page
     if ( ! mHelpLabel ) {
       mHelpLabel = new QLabel(this);
+      mHelpLabel->setTextFormat(Qt::RichText);
+      // mHelpLabel->setMinimumHeight(400);
       mHelpLabel->setMargin( KDialog::marginHint() );
       mHelpLabel->setText( i18n( "<qt><h2>The Document Items List is still empty, but Items "
                                  "can be added now.</h2>"
                                  "To add items to the document either "
                                  "<ul>"
-                                 "<li>Press the 'Add' button.</li>"
-                                 "<li>Open the template catalog clicking on the '%1' "
-                                  "button on the right and select from available templates.</li>"
+                                 "<li>Press the 'Add item' button above.</li>"
+                                 "<li>Open the template catalog by clicking on the '%1' "
+                                  "button on the right and pick one of the available templates.</li>"
                                    "</ul></qt>").arg( i18n( "show Template" ) ) );
       mHelpLabel->setWordWrap(true);
+      mHelpLabel->setMinimumHeight(200);
       m_positionScroll->addChild( mHelpLabel, 0);
     }
     return;
@@ -825,8 +826,15 @@ void KraftView::slotDocTypeChanged( const QString& newType )
   while( it.hasNext() ) {
     PositionViewWidget *w = it.next();
     w->slotEnableKindMenu( docType.allowAlternative() );
+    w->slotShowPrice(docType.pricesVisible());
   }
 
+  mAssistant->postCard()->slotShowPrices( docType.pricesVisible() );
+  m_footerEdit->_taxGroup->setVisible( docType.pricesVisible() );
+  KraftDocPositionsEdit *w = dynamic_cast<KraftDocPositionsEdit*>(mViewStack->widget(mDocPosEditorIndx));
+  if(w) {
+      w->setDiscountButtonVisible(docType.pricesVisible());
+  }
 }
 
 void KraftView::slotLanguageSettings()
@@ -944,8 +952,11 @@ void KraftView::slotAddItem( Katalog *kat, CatalogTemplate *tmpl )
       dp->setAmount( mRememberAmount );
     }
 
-    dia->setDocPosition( dp, newTemplate );
-
+    KraftDoc *doc = getDocument();
+    if(doc) {
+        DocType docType = doc->docType();
+        dia->setDocPosition( dp, newTemplate, docType.pricesVisible() );
+    }
     DocPositionList list = currentPositionList();
     dia->setPositionList( list, newpos );
 
@@ -1024,6 +1035,11 @@ void KraftView::slotAddItem( Katalog *kat, CatalogTemplate *tmpl )
   widget->slotModified();
   widget->slotAllowIndividualTax( currentTaxSetting() == DocPositionBase::TaxIndividual );
 
+  const QString dt = getDocument()->docType();
+  if( !dt.isEmpty() ) {
+      DocType docType(dt);
+      widget->slotShowPrice(docType.pricesVisible());
+  }
   slotFocusItem( widget, newpos );
   refreshPostCard();
 }
