@@ -38,13 +38,13 @@
 #include <kdebug.h>
 #include <kstandardaction.h>
 #include <kstandardshortcut.h>
-#include <kaction.h>
 #include <kcmdlineargs.h>
 #include <krun.h>
 #include <kapplication.h>
 #include <akonadi/control.h>
 #include <kabc/addressee.h>
 #include <ktoolinvocation.h>
+#include <kstandarddirs.h>
 
 // application specific includes
 #include "kraftview.h"
@@ -64,7 +64,6 @@
 #include "archiveman.h"
 #include "reportgenerator.h"
 #include "kraftsettings.h"
-#include "prefsdialog.h"
 #include "defaultprovider.h"
 #include "archdoc.h"
 #include "newdocassistant.h"
@@ -192,9 +191,9 @@ void Portal::initActions()
 
   actOpenArchivedDocument->setEnabled( false );
   // use the absolute path to your kraftui.rc file for testing purpose in createGUI();
-  char *prjPath = getenv("KRAFT_HOME");
-  if( prjPath ) {
-      createGUI(QString(prjPath)+"/src/kraftui.rc");
+  QString prjPath = QString::fromUtf8(qgetenv("KRAFT_HOME"));
+  if( !prjPath.isEmpty() ) {
+      createGUI(QString("%1/src/kraftui.rc").arg(prjPath));
   } else {
       createGUI( "kraftui.rc");
   }
@@ -304,6 +303,7 @@ void Portal::slotStartupChecks()
     actNewDocument->setEnabled( false );
     actPrintDocument->setEnabled( false );
     actCopyDocument->setEnabled( false );
+    actFollowDocument->setEnabled(false);
     actOpenDocument->setEnabled( false );
     actViewDocument->setEnabled( false );
     actOpenArchivedDocument->setEnabled( false );
@@ -330,11 +330,7 @@ void Portal::slotStartupChecks()
 
     // Fetch my address
     QString myUid = KraftSettings::self()->userUid();
-    if( myUid.isEmpty() ) {
-      QString myName = KraftSettings::self()->userName();
-      kDebug() << "Got My Name: " << myName;
-      mAddressProvider->getAddresseeByName( myName );
-    } else {
+    if( ! myUid.isEmpty() ) {
       kDebug() << "Got My UID: " << myUid;
       mAddressProvider->getAddressee( myUid );
     }
@@ -509,15 +505,16 @@ void Portal::slotPrintDocument()
   busyCursor( true );
   slotStatusMsg( i18n( "Generating PDF..." ) );
   DocumentMan *docman = DocumentMan::self();
-  DocGuardedPtr docPtr = docman->openDocument( locId );
+  _currentDoc = docman->openDocument( locId );
   QString ident;
-  if ( docPtr ) ident = docPtr->ident();
 
-  if( docPtr ) {
-    ArchiveMan *archman = ArchiveMan::self();
-    dbID archID = archman->archiveDocument( docPtr );
-    slotPrintDocument( ident, archID );
-    // m_portalView->docDigestView()->addArchivedItem(docPtr->docID(), archID);
+  if ( _currentDoc ) {
+      ident = _currentDoc->ident();
+
+      ArchiveMan *archman = ArchiveMan::self();
+      dbID archID = archman->archiveDocument( _currentDoc );
+      slotPrintDocument( ident, archID );
+      // m_portalView->docDigestView()->addArchivedItem(docPtr->docID(), archID);
   }
   busyCursor( false );
   slotStatusMsg( i18n( "Ready." ) );
@@ -590,6 +587,36 @@ void Portal::slotOpenPdf( const QString& fileName )
     disconnect( ReportGenerator::self(), SIGNAL( pdfAvailable( const QString& ) ),0,0 );
     KUrl url( fileName );
     KRun::runUrl( url, "application/pdf", this );
+
+    // save pdf into a <customer>/<dockind> structure
+    if( _currentDoc ) {
+        QString uid = _currentDoc->addressUid();
+        QString docType = _currentDoc->docType();
+
+        if( !uid.isEmpty() ) {
+            KStandardDirs stdDirs;
+
+            QString outputDir = KraftSettings::self()->pdfOutputDir();
+            if ( outputDir.isEmpty() ) {
+                outputDir = stdDirs.saveLocation( "data", "kraft/archivePdf", true );
+            }
+
+            if ( ! outputDir.endsWith( "/" ) ) outputDir += QLatin1String("/");
+            QDir customerDir(outputDir + QString("%1/%2").arg(uid).arg(docType));
+            if( !customerDir.exists() ) {
+                customerDir.mkpath( customerDir.absolutePath());
+            }
+            if( customerDir.exists() ) {
+                QFileInfo fi(fileName);
+                QString target = customerDir.canonicalPath() + QLatin1Char('/') + fi.fileName();
+                QFileInfo tfi(target);
+                if( tfi.exists() ) {
+                    QFile::remove(target);
+                }
+                QFile::copy( fileName, target );
+            }
+        }
+    }
 }
 
 void Portal::slotOpenDocument( const QString& id )
