@@ -245,6 +245,12 @@ void PositionViewWidget::setDocPosition( DocPositionBase *dp, KLocale* loc )
   m_skipModifiedSignal = false;
 }
 
+void PositionViewWidget::slotShowPrice( bool show )
+{
+    m_sumLabel->setVisible(show);
+    m_sbUnitPrice->setVisible(show);
+}
+
 void PositionViewWidget::slotUpdateTagToolTip()
 {
   QString tip;
@@ -681,7 +687,7 @@ void PositionViewWidget::paintEvent ( QPaintEvent* )
   QPainter *painter;
   painter = new QPainter( this );
 
-  // visualise the tags
+  // visualize the tags
   QStringList taglist = tagList();
   if ( taglist.count() ) {
     int share = ( height() - 24 ) / taglist.count();
