@@ -1,5 +1,5 @@
 /***************************************************************************
-                       archiveman.cpp  - Archive Manager
+                     Report Generator based on Reportlab
                              -------------------
     begin                : July 2006
     copyright            : (C) 2006 by Klaas Freitag
@@ -69,6 +69,7 @@ ReportGenerator::ReportGenerator()
   mAddressProvider = new AddressProvider( this );
   connect( mAddressProvider, SIGNAL( addresseeFound( const QString&, const KABC::Addressee& )),
            this, SLOT( slotAddresseeFound( const QString&, const KABC::Addressee& ) ) );
+
   connect( mAddressProvider, SIGNAL( finished(int) ),
            this, SLOT( slotAddresseeSearchFinished(int)) );
 }
@@ -177,7 +178,7 @@ void ReportGenerator::slotAddresseeSearchFinished( int )
   QString tmplFile = findTemplate( mArchDoc->docType() );
 
   if ( tmplFile.isEmpty() ) {
-    kDebug() << "tmplFile is emty!";
+    kDebug() << "tmplFile is empty!";
     return;
   } else {
     kDebug() << "Reading this template: " << tmplFile;
@@ -185,6 +186,9 @@ void ReportGenerator::slotAddresseeSearchFinished( int )
 
   // create a text template
   TextTemplate tmpl( tmplFile );
+  if( !tmpl.open() ) {
+      return;
+  }
 
   /* replace the placeholders */
   /* A placeholder has the format <!-- %VALUE --> */
@@ -439,9 +443,9 @@ QStringList ReportGenerator::findTrml2Pdf( )
       }
     } else {
       // tool erml2pdf.py not found. Check in $KRAFT_HOME/tools
-      QString p = QString::fromLocal8Bit( getenv( "KRAFT_HOME"));
+      QString p = QString::fromUtf8(qgetenv("KRAFT_HOME"));
       if( !p.isEmpty() ) {
-          p += "/tools/erml2pdf.py";
+          p += QLatin1String("/tools/erml2pdf.py");
           kDebug() << "Found erml2pdf from KRAFT_HOME: " << p;
           if( QFile::exists( p ) ) {
               retList << "python";
